Command-line usage — savepagenow documentation

# Command-line usage

The Python library is also installed as a command-line interface. You can run it from your terminal like so:

The command has the same options as the Python API.

## savepagenow

> Archive the provided URL using archive.org’s Wayback Machine.

> Raises a CachedPage exception if archive.org declines to conduct a new capture and returns a previous snapshot instead.

    savepagenow [OPTIONS] URL

Options

-ua, --user-agent <user_agent>

  User-Agent header for the web request

-c, --accept-cache

  Accept and return cached URL

Arguments

URL

  Required argument

## Developing the CLI

The command-line interface is implemented using Click and setuptools. To install it locally for development inside your virtual environment, run the following installation command, as prescribed by the Click documentation.

    pip install --editable .